==> typolight-2.6.2.tar.gz: typolight-2.6.2/system/modules/rep_client/languages/de/tl_repository.php <==
<?php
/**
 * TL_ROOT/system/modules/rep_client/languages/de/tl_repository.php 
 * 
 * TYPOlight extension: rep_client 1.0.0 rc1 
 * German translation file 
 * 
 * Copyright : (c)  2008 IBK Software AG 
 * License   : GNU LGPL V3 
 * Author    : Peter Koch (acenes), http://contifex.com 
 * Translator: Peter Koch (acenes), http://contifex.com 
 */

/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_repository']['lickey']        = array('Lizenzschlüssel', 'Eingabe des beim Erweiterungshersteller erworbenen Lizenzschlüssels.');
$GLOBALS['TL_LANG']['tl_repository']['uninstprotect'] = array('Löschgeschützt', 'Erweiterung gegen versehentliches Löschen schützen.');

/**
 * References
 */
$GLOBALS['TL_LANG']['tl_repository']['action']             = 'Aktion';
$GLOBALS['TL_LANG']['tl_repository']['actionsummary']      = 'Aktionszusammenfassung';
$GLOBALS['TL_LANG']['tl_repository']['actionsuccess']      = 'Aktion erfolgreich.';
$GLOBALS['TL_LANG']['tl_repository']['actionfailed']       = 'Eine oder mehrere Aktionen gescheitert.';
$GLOBALS['TL_LANG']['tl_repository']['apply']              = 'Anwenden';
$GLOBALS['TL_LANG']['tl_repository']['byorder']            = 'Nach %s';
$GLOBALS['TL_LANG']['tl_repository']['checkextension']     = 'Erweiterung prüfen';
$GLOBALS['TL_LANG']['tl_repository']['dbuptodate']         = 'Die Datenbank ist aktuell';
$GLOBALS['TL_LANG']['tl_repository']['deletingdirs']       = 'Lösche Verzeichnisse';
$GLOBALS['TL_LANG']['tl_repository']['deletingfiles']      = 'Lösche Dateien';
$GLOBALS['TL_LANG']['tl_repository']['editextension']      = 'Einstellungen bearbeiten';
$GLOBALS['TL_LANG']['tl_repository']['extinstrecntf']      = 'Installationsdatensatz der Erweiterung nicht gefunden';
$GLOBALS['TL_LANG']['tl_repository']['errdldpkg']          = 'Download des Pakets vom Repository ist fehlgeschlagen.';
$GLOBALS['TL_LANG']['tl_repository']['failed']             = 'fehlgeschlagen';
$GLOBALS['TL_LANG']['tl_repository']['fileerrwrite']       = 'Fehler beim schreiben von Datei %s';
$GLOBALS['TL_LANG']['tl_repository']['filesdeleted']       = '%s Datei(en) gelöscht';
$GLOBALS['TL_LANG']['tl_repository']['filesinstalled']     = '%s Datei(en) installiert';
$GLOBALS['TL_LANG']['tl_repository']['filesunchanged']     = '%s Datei(en) unverändert';
$GLOBALS['TL_LANG']['tl_repository']['filesupdated']       = '%s Datei(en) aktualisiert';
$GLOBALS['TL_LANG']['tl_repository']['goback']             = 'Zurück';
$GLOBALS['TL_LANG']['tl_repository']['install']            = 'Installieren';
$GLOBALS['TL_LANG']['tl_repository']['installextension']   = 'Erweiterung installieren/aktualisieren';
$GLOBALS['TL_LANG']['tl_repository']['installingext']      = 'Installation %s %s Build %s';
$GLOBALS['TL_LANG']['tl_repository']['installlogtitle']    = 'Datei Installation/Update-Log';
$GLOBALS['TL_LANG']['tl_repository']['lickeyrequired']     = 'Diese Erweiterung benötigt einen Lizenzschlüssel. Bitte erwerben Sie diesen beim Anbieter.';
$GLOBALS['TL_LANG']['tl_repository']['none']               = 'keine';
$GLOBALS['TL_LANG']['tl_repository']['notfound']           = 'nicht gefunden';
$GLOBALS['TL_LANG']['tl_repository']['ok']                 = 'OK';
$GLOBALS['TL_LANG']['tl_repository']['okuninstextension']  = 'OK zur Deinstallation von <em>%s</em>?';
$GLOBALS['TL_LANG']['tl_repository']['showdetails']        = 'Detailanzeige';
$GLOBALS['TL_LANG']['tl_repository']['stateshint']         = 'Wählen Sie die gewünschten Stati aus.';
$GLOBALS['TL_LANG']['tl_repository']['status']             = 'Status';
$GLOBALS['TL_LANG']['tl_repository']['success']            = 'erfolgreich';
$GLOBALS['TL_LANG']['tl_repository']['uninstallextension'] = 'Erweiterung deinstallieren';
$GLOBALS['TL_LANG']['tl_repository']['updatedatabase']     = 'Datenbank prüfen/aktualisieren';
$GLOBALS['TL_LANG']['tl_repository']['updateextension']    = 'Erweiterung aktualisieren';
$GLOBALS['TL_LANG']['tl_repository']['update']             = 'Aktualisierung';
$GLOBALS['TL_LANG']['tl_repository']['updates']            = 'Aktualisierungen';
$GLOBALS['TL_LANG']['tl_repository']['updatehint']         = 'Stati auswählen, zu denen aktualisiert werden soll.';
$GLOBALS['TL_LANG']['tl_repository']['updatingext']        = 'Aktualisierung %s %s Build %s';
$GLOBALS['TL_LANG']['tl_repository']['validate']           = 'Reparieren';
$GLOBALS['TL_LANG']['tl_repository']['validatingext']      = 'Prüfung/Reparatur %s %s Build %s';

/**
 * Status messages
 */
$GLOBALS['TL_LANG']['tl_repository']['statext']['uptodate']        = 'Aktuell.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['notapproved']     = 'Nicht erprobt für %s %s.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['notapprovedwith'] = 'Nicht erprobt mit %s %s.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['newversion']      = 'Neue Version %s Build %s verfügbar.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['depmissing']      = 'Benötigte Erweiterung %s fehlt.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['extnotfound']     = 'Erweiterung im Verzeichnis nicht gefunden.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['vernotfound']     = 'Installierte Version im Verzeichnis nicht gefunden.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['extneedkey']      = 'Lizenzschlüssel benötigt, Erweiterung vorgängig installieren.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['errorinstall']    = 'Beschädigt, Aktualisierung/Reparatur notwendig.';
 
?>

==> typolight-2.6.7.tar.gz: typolight-2.6.7/system/modules/rep_client/languages/de/tl_repository.php <==
<?php
/**
 * TL_ROOT/system/modules/rep_client/languages/de/tl_repository.php 
 * 
 * TYPOlight extension: rep_client 1.0.0 rc1 
 * German translation file 
 * 
 * Copyright : (c)  2008 IBK Software AG 
 * License   : GNU LGPL V3 
 * Author    : Peter Koch (acenes), http://contifex.com 
 * Translator: Peter Koch (acenes), http://contifex.com 
 */

/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_repository']['lickey']        = array('Lizenzschlüssel', 'Eingabe des beim Erweiterungshersteller erworbenen Lizenzschlüssels.');
$GLOBALS['TL_LANG']['tl_repository']['uninstprotect'] = array('Löschgeschützt', 'Erweiterung gegen versehentliches Löschen schützen.');

/**
 * References
 */
$GLOBALS['TL_LANG']['tl_repository']['action']             = 'Aktion';
$GLOBALS['TL_LANG']['tl_repository']['actionsummary']      = 'Aktionszusammenfassung';
$GLOBALS['TL_LANG']['tl_repository']['actionsuccess']      = 'Aktion erfolgreich.';
$GLOBALS['TL_LANG']['tl_repository']['actionfailed']       = 'Eine oder mehrere Aktionen gescheitert.';
$GLOBALS['TL_LANG']['tl_repository']['apply']              = 'Anwenden';
$GLOBALS['TL_LANG']['tl_repository']['byorder']            = 'Nach %s';
$GLOBALS['TL_LANG']['tl_repository']['checkextension']     = 'Erweiterung prüfen';
$GLOBALS['TL_LANG']['tl_repository']['dbuptodate']         = 'Die Datenbank ist aktuell';
$GLOBALS['TL_LANG']['tl_repository']['deletingdirs']       = 'Lösche Verzeichnisse';
$GLOBALS['TL_LANG']['tl_repository']['deletingfiles']      = 'Lösche Dateien';
$GLOBALS['TL_LANG']['tl_repository']['editextension']      = 'Einstellungen bearbeiten';
$GLOBALS['TL_LANG']['tl_repository']['extinstrecntf']      = 'Installationsdatensatz der Erweiterung nicht gefunden';
$GLOBALS['TL_LANG']['tl_repository']['errdldpkg']          = 'Download des Pakets vom Repository ist fehlgeschlagen.';
$GLOBALS['TL_LANG']['tl_repository']['failed']             = 'fehlgeschlagen';
$GLOBALS['TL_LANG']['tl_repository']['fileerrwrite']       = 'Fehler beim schreiben von Datei %s';
$GLOBALS['TL_LANG']['tl_repository']['filesdeleted']       = '%s Datei(en) gelöscht';
$GLOBALS['TL_LANG']['tl_repository']['filesinstalled']     = '%s Datei(en) installiert';
$GLOBALS['TL_LANG']['tl_repository']['filesunchanged']     = '%s Datei(en) unverändert';
$GLOBALS['TL_LANG']['tl_repository']['filesupdated']       = '%s Datei(en) aktualisiert';
$GLOBALS['TL_LANG']['tl_repository']['goback']             = 'Zurück';
$GLOBALS['TL_LANG']['tl_repository']['install']            = 'Installieren';
$GLOBALS['TL_LANG']['tl_repository']['installextension']   = 'Erweiterung installieren/aktualisieren';
$GLOBALS['TL_LANG']['tl_repository']['installingext']      = 'Installation %s %s Build %s';
$GLOBALS['TL_LANG']['tl_repository']['installlogtitle']    = 'Datei Installation/Update-Log';
$GLOBALS['TL_LANG']['tl_repository']['lickeyrequired']     = 'Diese Erweiterung benötigt einen Lizenzschlüssel. Bitte erwerben Sie diesen beim Anbieter.';
$GLOBALS['TL_LANG']['tl_repository']['none']               = 'keine';
$GLOBALS['TL_LANG']['tl_repository']['notfound']           = 'nicht gefunden';
$GLOBALS['TL_LANG']['tl_repository']['ok']                 = 'OK';
$GLOBALS['TL_LANG']['tl_repository']['okuninstextension']  = 'OK zur Deinstallation von <em>%s</em>?';
$GLOBALS['TL_LANG']['tl_repository']['showdetails']        = 'Detailanzeige';
$GLOBALS['TL_LANG']['tl_repository']['stateshint']         = 'Wählen Sie die gewünschten Stati aus.';
$GLOBALS['TL_LANG']['tl_repository']['status']             = 'Status';
$GLOBALS['TL_LANG']['tl_repository']['success']            = 'erfolgreich';
$GLOBALS['TL_LANG']['tl_repository']['uninstallextension'] = 'Erweiterung deinstallieren';
$GLOBALS['TL_LANG']['tl_repository']['updatedatabase']     = 'Datenbank prüfen/aktualisieren';
$GLOBALS['TL_LANG']['tl_repository']['updateextension']    = 'Erweiterung aktualisieren';
$GLOBALS['TL_LANG']['tl_repository']['update']             = 'Aktualisierung';
$GLOBALS['TL_LANG']['tl_repository']['updates']            = 'Aktualisierungen';
$GLOBALS['TL_LANG']['tl_repository']['updatehint']         = 'Stati auswählen, zu denen aktualisiert werden soll.';
$GLOBALS['TL_LANG']['tl_repository']['updatingext']        = 'Aktualisierung %s %s Build %s';
$GLOBALS['TL_LANG']['tl_repository']['validate']           = 'Reparieren';
$GLOBALS['TL_LANG']['tl_repository']['validatingext']      = 'Prüfung/Reparatur %s %s Build %s';

/**
 * Status messages
 */
$GLOBALS['TL_LANG']['tl_repository_statext']['uptodate']        = 'Aktuell.';
$GLOBALS['TL_LANG']['tl_repository_statext']['notapproved']     = 'Nicht erprobt für %s %s.';
$GLOBALS['TL_LANG']['tl_repository_statext']['notapprovedwith'] = 'Nicht erprobt mit %s %s.';
$GLOBALS['TL_LANG']['tl_repository_statext']['newversion']      = 'Neue Version %s Build %s verfügbar.';
$GLOBALS['TL_LANG']['tl_repository_statext']['depmissing']      = 'Benötigte Erweiterung %s fehlt.';
$GLOBALS['TL_LANG']['tl_repository_statext']['extnotfound']     = 'Erweiterung im Verzeichnis nicht gefunden.';
$GLOBALS['TL_LANG']['tl_repository_statext']['vernotfound']     = 'Installierte Version im Verzeichnis nicht gefunden.';
$GLOBALS['TL_LANG']['tl_repository_statext']['extneedkey']      = 'Lizenzschlüssel benötigt, Erweiterung vorgängig installieren.';
$GLOBALS['TL_LANG']['tl_repository_statext']['errorinstall']    = 'Beschädigt, Aktualisierung/Reparatur notwendig.';
 
?>
